@@ -7,13 +7,13 @@ from . import cli
 
 @cli.command()
 @click.option("-p", "--port", default=12001, help="Local port to listen on")
+@click.option("-v", "--verbose", count=True, help="Verbosity level")
 @click.argument("host", type=str, nargs=1)
-def proxy(port, host):
+def proxy(port, verbose, host):
     """Start a ssh proxy on local port to remove host."""
     click.secho(f"Starting proxy to {host} on port {port}", fg="green")
 
-    cmd = [
-        "autossh",
+    options = [
         "-M", "0",
         "-o", "ServerAliveInterval 10",
         "-o", "ServerAliveCountMax 3",
@@ -21,6 +21,10 @@ def proxy(port, host):
         "-N",
         "-S", "none",
         "-D", f"127.0.0.1:{port}",
-        host
     ]
+
+    for _ in range(verbose):
+        options.append("-v")
+
+    cmd = ["autossh"] + options + [host]
     run(cmd, check=True)
